@@ -1,7 +1,9 @@
 """Provide a model for the Z-Wave JS controller."""
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
 from typing import TYPE_CHECKING, Any, Dict, List, Literal, Optional, Union, cast
 
+from zwave_js_server.model.firmware import FirmwareUpdateFileInfo, FirmwareUpdateInfo
+
 from ...const import (
     MINIMUM_QR_STRING_LENGTH,
     InclusionState,
@@ -691,6 +693,46 @@ class Controller(EventBase):
             for node_id, lifeline_routes in data["routes"].items()
         }
 
+    async def async_is_any_ota_firmware_update_in_progress(self) -> bool:
+        """
+        Send isAnyOTAFirmwareUpdateInProgress command to Controller.
+
+        If `True`, a firmware update is in progress on at least one node.
+        """
+        data = await self.client.async_send_command(
+            {"command": "controller.is_any_ota_firmware_update_in_progress"},
+            require_schema=21,
+        )
+        assert data
+        return cast(bool, data["progress"])
+
+    async def async_get_available_firmware_updates(
+        self, node: Node
+    ) -> List[FirmwareUpdateInfo]:
+        """Send getAvailableFirmwareUpdates command to Controller."""
+        data = await self.client.async_send_command(
+            {
+                "command": "controller.get_available_firmware_updates",
+                "nodeId": node.node_id,
+            },
+            require_schema=21,
+        )
+        assert data
+        return [FirmwareUpdateInfo.from_dict(update) for update in data["updates"]]
+
+    async def async_begin_ota_firmware_update(
+        self, node: Node, update: FirmwareUpdateFileInfo
+    ) -> None:
+        """Send beginOTAFirmwareUpdate command to Controller."""
+        await self.client.async_send_command(
+            {
+                "command": "controller.begin_ota_firmware_update",
+                "nodeId": node.node_id,
+                "update": asdict(update),
+            },
+            require_schema=21,
+        )
+
     def receive_event(self, event: Event) -> None:
         """Receive an event."""
         if event.data["source"] == "node":
@@ -733,6 +775,9 @@ class Controller(EventBase):
     def handle_exclusion_stopped(self, event: Event) -> None:
         """Process an exclusion stopped event."""
 
+    def handle_node_found(self, event: Event) -> None:
+        """Process a node found event."""
+
     def handle_node_added(self, event: Event) -> None:
         """Process a node added event."""
         node = event.data["node"] = Node(self.client, event.data["node"])
