@@ -4,6 +4,7 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
 
 from ...const import (
     INTERVIEW_FAILED,
+    NOT_INTERVIEWED,
     CommandClass,
     NodeStatus,
     PowerLevel,
@@ -21,6 +22,8 @@ from ..device_class import DeviceClass
 from ..device_config import DeviceConfig
 from ..endpoint import Endpoint
 from ..firmware import (
+    FirmwareUpdateCapabilities,
+    FirmwareUpdateCapabilitiesDataType,
     FirmwareUpdateFinished,
     FirmwareUpdateFinishedDataType,
     FirmwareUpdateProgress,
@@ -33,6 +36,8 @@ from ..notification import (
     NotificationNotificationDataType,
     PowerLevelNotification,
     PowerLevelNotificationDataType,
+    MultilevelSwitchNotification,
+    MultilevelSwitchNotificationDataType,
 )
 from ..value import (
     ConfigurationValue,
@@ -69,8 +74,8 @@ class Node(EventBase):
         super().__init__()
         self.client = client
         self.data: NodeDataType = {}
-        self._device_config: DeviceConfig = DeviceConfig({})
-        self._statistics: NodeStatistics = NodeStatistics()
+        self._device_config = DeviceConfig({})
+        self._statistics = NodeStatistics(client, data.get("statistics"))
         self._firmware_update_progress: Optional[FirmwareUpdateProgress] = None
         self.values: Dict[str, Union[ConfigurationValue, Value]] = {}
         self.endpoints: Dict[int, Endpoint] = {}
@@ -267,7 +272,16 @@ class Node(EventBase):
     @property
     def in_interview(self) -> bool:
         """Return whether node is currently being interviewed."""
-        return not self.ready and self.interview_stage != INTERVIEW_FAILED
+        return (
+            not self.ready
+            and not self.awaiting_manual_interview
+            and self.interview_stage != INTERVIEW_FAILED
+        )
+
+    @property
+    def awaiting_manual_interview(self) -> bool:
+        """Return whether node requires a manual interview."""
+        return self.interview_stage in (None, NOT_INTERVIEWED)
 
     @property
     def command_classes(self) -> List[CommandClassInfo]:
@@ -305,7 +319,7 @@ class Node(EventBase):
         """Update the internal state data."""
         self.data = data
         self._device_config = DeviceConfig(self.data.get("deviceConfig", {}))
-        self._statistics = NodeStatistics(self.data.get("statistics"))
+        self._statistics = NodeStatistics(self.client, self.data.get("statistics"))
 
         # Remove stale values
         value_ids = (_get_value_id_from_dict(self, val) for val in data["values"])
@@ -494,9 +508,37 @@ class Node(EventBase):
         )
         return ValueMetadata(cast(MetaDataType, data))
 
+    async def async_get_firmware_update_capabilities(
+        self,
+    ) -> FirmwareUpdateCapabilities:
+        """Send getFirmwareUpdateCapabilities command to Node."""
+        data = await self.async_send_command(
+            "get_firmware_update_capabilities",
+            require_schema=7,
+            wait_for_result=True,
+        )
+        assert data
+        return FirmwareUpdateCapabilities(
+            cast(FirmwareUpdateCapabilitiesDataType, data["capabilities"])
+        )
+
+    async def async_get_firmware_update_capabilities_cached(
+        self,
+    ) -> FirmwareUpdateCapabilities:
+        """Send getFirmwareUpdateCapabilitiesCached command to Node."""
+        data = await self.async_send_command(
+            "get_firmware_update_capabilities_cached",
+            require_schema=21,
+            wait_for_result=True,
+        )
+        assert data
+        return FirmwareUpdateCapabilities(
+            cast(FirmwareUpdateCapabilitiesDataType, data["capabilities"])
+        )
+
     async def async_abort_firmware_update(self) -> None:
         """Send abortFirmwareUpdate command to Node."""
-        await self.async_send_command("abort_firmware_update", wait_for_result=False)
+        await self.async_send_command("abort_firmware_update", wait_for_result=True)
 
     async def async_poll_value(self, val: Union[Value, str]) -> None:
         """Send pollValue command to Node for given value (or value_id)."""
@@ -551,12 +593,12 @@ class Node(EventBase):
         return SecurityClass(data["highestSecurityClass"])
 
     async def async_test_power_level(
-        self, test_node_id: int, power_level: PowerLevel, test_frame_count: int
+        self, test_node: "Node", power_level: PowerLevel, test_frame_count: int
     ) -> int:
         """Send testPowerLevel command to Node."""
         data = await self.async_send_command(
             "test_powerlevel",
-            testNodeId=test_node_id,
+            testNodeId=test_node.node_id,
             powerlevel=power_level,
             testFrameCount=test_frame_count,
             require_schema=13,
@@ -582,10 +624,10 @@ class Node(EventBase):
         return LifelineHealthCheckSummary(data["summary"])
 
     async def async_check_route_health(
-        self, target_node_id: int, rounds: Optional[int] = None
+        self, target_node: "Node", rounds: Optional[int] = None
     ) -> RouteHealthCheckSummary:
         """Send checkRouteHealth command to Node."""
-        kwargs = {"targetNodeId": target_node_id}
+        kwargs = {"targetNodeId": target_node.node_id}
         if rounds is not None:
             kwargs["rounds"] = rounds
         data = await self.async_send_command(
@@ -642,6 +684,18 @@ class Node(EventBase):
         )
         self.data["location"] = location
 
+    async def async_is_firmware_update_in_progress(self) -> bool:
+        """
+        Send isFirmwareUpdateInProgress command to Node.
+
+        If `True`, a firmware update for this node is in progress.
+        """
+        data = await self.async_send_command(
+            "is_firmware_update_in_progress", require_schema=21, wait_for_result=True
+        )
+        assert data
+        return cast(bool, data["progress"])
+
     async def async_set_keep_awake(self, keep_awake: bool) -> None:
         """Set node keep awake state."""
         await self.async_send_command(
@@ -783,6 +837,10 @@ class Node(EventBase):
             event.data["notification"] = NotificationNotification(
                 self, cast(NotificationNotificationDataType, event.data)
             )
+        elif command_class == CommandClass.SWITCH_MULTILEVEL:
+            event.data["notification"] = MultilevelSwitchNotification(
+                self, cast(MultilevelSwitchNotificationDataType, event.data)
+            )
         elif command_class == CommandClass.ENTRY_CONTROL:
             event.data["notification"] = EntryControlNotification(
                 self, cast(EntryControlNotificationDataType, event.data)
@@ -811,5 +869,7 @@ class Node(EventBase):
 
     def handle_statistics_updated(self, event: Event) -> None:
         """Process a statistics updated event."""
-        self._statistics.data.update(event.data["statistics"])
-        event.data["statistics_updated"] = self.statistics
+        self.data["statistics"] = statistics = event.data["statistics"]
+        event.data["statistics_updated"] = self._statistics = NodeStatistics(
+            self.client, statistics
+        )
